from setuptools import setup

setup(
    name='enigma_aps',
    version='1.0.0',
    py_modules=['funções'],
    url='https://github.com/gabrielfmendes/enigma_aps',
    license='MIT',
    author='Gabriel Mendes',
    author_email='gabrielfmm@al.insper.edu.br',
    description='Uma biblioteca que contém funções para cifrar e decifrar mensagens usando uma simulação da máquina enigma.',
)
